@@ -141,7 +141,7 @@ class ConfigBuilder(object):
 
     def __init__(self, template_dir=None, template_name=None,
                  cache_dir=None, cache_expiry=CachedObject.DEFAULT_EXPIRY,
-                 bgpq3_path="bgpq3", bgpq3_host=IRRDBInfo.BGPQ3_DEFAULT_HOST,
+                 bgpq3_path="bgpq4", bgpq3_host=IRRDBInfo.BGPQ3_DEFAULT_HOST,
                  bgpq3_sources=IRRDBInfo.BGPQ3_DEFAULT_SOURCES,
                  rtt_getter_path=None, threads=4,
                  ip_ver=None, perform_graceful_shutdown=False,
@@ -733,7 +733,7 @@ class BIRDConfigBuilder(ConfigBuilder):
     IGNORABLE_ISSUES = ["max_prefix_count_rejected_routes"]
 
     AVAILABLE_VERSION = ["1.6.3", "1.6.4", "1.6.6", "1.6.7", "1.6.8",
-                         "2.0.7", "2.0.7+b962967e"]
+                         "2.0.7", "2.0.7+b962967e", "2.0.8"]
     DEFAULT_VERSION = "1.6.8"
 
     def validate_bgpspeaker_specific_configuration(self):
@@ -867,8 +867,8 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
     AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7",
-                         "6.8"]
-    DEFAULT_VERSION = "6.7"
+                         "6.8", "6.9"]
+    DEFAULT_VERSION = AVAILABLE_VERSION[-1]
 
     IGNORABLE_ISSUES = ["path_hiding", "transit_free_action",
                         "add_path", "max_prefix_action",
@@ -877,7 +877,7 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
                         "large_communities", "extended_communities",
                         "graceful_shutdown", "internal_communities",
                         "rpki_roas_as_route_objects_source",
-                        "rpki_roas_source"]
+                        "rpki_roas_source", "path_hiding_69"]
 
     def _include_local_file(self, local_file_id):
         return 'include "{}"\n\n'.format(
@@ -890,16 +890,40 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     def validate_bgpspeaker_specific_configuration(self):
         res = True
 
-        if self.cfg_general["path_hiding"]:
+        if self.cfg_general["path_hiding"] and \
+            version.parse(self.target_version) < version.parse("6.9"):
             if not self.process_bgpspeaker_specific_compatibility_issue(
                 "path_hiding",
                 "The 'path_hiding' general configuration parameter is "
                 "set to True, but the configuration generated by "
-                "ARouteServer for OpenBGPD does not support "
+                "ARouteServer for OpenBGPD < 6.9 does not support "
                 "path-hiding mitigation techniques."
             ):
                 res = False
 
+        if self.cfg_general["path_hiding"] and \
+            version.parse(self.target_version) == version.parse("6.9"):
+            if not self.process_bgpspeaker_specific_compatibility_issue(
+                "path_hiding_69",
+                "The 'path_hiding' general configuration parameter is "
+                "set to True, however, for version 6.9 of OpenBGPD, "
+                "some issues were observed that may affect the security "
+                "and stability of the BGP routing ecosystem: please see "
+                "the docs referenced below, and acknowledge this error "
+                "as reported at the end of this message only if you "
+                "applied the patches or if you strongly believe that "
+                "those issues will not affect your deployment and the "
+                "global stability of the Internet routing.\n"
+                "Information about those issues can be found here:\n"
+                "- 2nd best route not getting withdrawn when 'rde "
+                "evaluate all' is configured "
+                "(https://marc.info/?l=openbsd-tech&m=162011500326166&w=2)\n"
+                "- 2nd best route not advertised when 'rde evaluate all' "
+                "is added and the daemon reloaded "
+                "(https://marc.info/?l=openbsd-tech&m=162021735205669&w=2)"
+            ):
+                res = False
+
         transit_free_action = self.cfg_general["filtering"]["transit_free"]["action"]
         if transit_free_action and transit_free_action != "reject":
             if not self.process_bgpspeaker_specific_compatibility_issue(
@@ -1140,23 +1164,51 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
         use_rpki_roas_as_route_objects_cfg = \
             self.cfg_general["filtering"]["irrdb"]["use_rpki_roas_as_route_objects"]
         if use_rpki_roas_as_route_objects_cfg["enabled"]:
-            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache":
+            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache" and \
+               version.parse(self.target_version) < version.parse("6.9"):
                 if not self.process_bgpspeaker_specific_compatibility_issue(
                     "rpki_roas_as_route_objects_source",
-                    "For OpenBGPD only the 'ripe-rpki-validator-cache' "
+                    "For OpenBGPD < 6.9 only the 'ripe-rpki-validator-cache' "
                     "value is allowed for the 'rpki_roas.source' option."
                 ):
                     res = False
 
         if self.cfg_general.rpki_roas_needed:
-            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache":
+            if self.cfg_general["rpki_roas"]["source"] != "ripe-rpki-validator-cache" and \
+               version.parse(self.target_version) < version.parse("6.9"):
                 if not self.process_bgpspeaker_specific_compatibility_issue(
                     "rpki_roas_source",
-                    "For OpenBGPD only the 'ripe-rpki-validator-cache' "
+                    "For OpenBGPD < 6.9 only the 'ripe-rpki-validator-cache' "
                     "value is allowed for the 'rpki_roas.source' option."
                 ):
                     res = False
 
+            if self.cfg_general["rpki_roas"]["source"] == "rtr" and \
+               version.parse(self.target_version) == version.parse("6.9"):
+                if not self.process_bgpspeaker_specific_compatibility_issue(
+                    "rpki_roas_source",
+                    "The general configuration policy has 'rpki_roas.source' "
+                    "set to 'rtr', which means that ROAs will be retrieved "
+                    "using one or more RTR sessions directly configured on "
+                    "the route-server. "
+                    "However, for version 6.9 of OpenBGPD, some issues were "
+                    "observed that may affect the operations: please verify "
+                    "whether these issues are considered relevant for your "
+                    "deployment scenario, and if you believe they are not "
+                    "relevant, or if you patched the daemon to circumvent "
+                    "them, please ignore this error as reported at the end of "
+                    "this message.\n"
+                    "Information about those issues can be found here:\n"
+                    "- 'Invalid argument' error on RTR session establishment "
+                    "(OpenBGPD 6.9p0 portable edition, issue #23 on GitHub "
+                    "https://github.com/openbgpd-portable/openbgpd-portable/"
+                    "issues/23)\n"
+                    "- Blocking `connect()` call that may lead to the daemon "
+                    "to block until the connection times out "
+                    "(https://marc.info/?l=openbsd-tech&m=162005636502085&w=2)"
+                ):
+                    res = False
+
         return res
 
     def enrich_j2_environment(self, env):
