@@ -95,6 +95,9 @@ class ConfigureCommand(ARouteServerCommand):
                 raise ARouteServerError("Aborted!")
             if answer_ok:
                 break
+            else:
+                if self.preset_answers:
+                    raise ARouteServerError("Pre-set answer is invalid!")
         self.answers[answer_id] = answer
 
     def ask_list_of_ip_prefixes(self, text, raise_exc=False):
@@ -242,11 +245,21 @@ class ConfigureCommand(ARouteServerCommand):
         cfg["router_id"] = self.answers["router_id"]
 
         if self.answers["daemon"] == "openbgpd":
-            self.notes.append(
-                "For OpenBGPD, path-hiding mitigation techniques are "
-                "not implemented."
-            )
-            cfg["path_hiding"] = False
+            if version.parse(self.answers["version"]) < version.parse("6.9"):
+                self.notes.append(
+                    "For OpenBGPD < 6.9, path-hiding mitigation techniques are "
+                    "not implemented."
+                )
+                cfg["path_hiding"] = False
+            elif version.parse(self.answers["version"]) == version.parse("6.9"):
+                self.notes.append(
+                    "For OpenBGPD 6.9, path-hiding mitigation is available, but "
+                    "it's not automatically configured because of some issues "
+                    "in the implementations of bgpd. "
+                    "Please refer to the CHANGELOG for the release 1.6.0 of "
+                    "ARouteServer for more details."
+                )
+                cfg["path_hiding"] = False
 
         cfg["filtering"] = OrderedDict()
         filtering = cfg["filtering"]
@@ -274,9 +287,8 @@ class ConfigureCommand(ARouteServerCommand):
 
         filtering["transit_free"] = {
             "action": "reject",
-            "asns": [174, 209, 286, 701, 1239, 1299, 2828, 2914,
-                     3257, 3320, 3356, 3549, 5511, 6453, 6461,
-                     6762, 6830, 7018, 12956]
+            "asns": [174, 701, 1299, 2914, 3257, 3320, 3356, 5511,
+                     6453, 6461, 6762, 6830, 7018, 12956]
         }
         filtering["never_via_route_servers"] = {
             "peering_db": True
@@ -349,8 +361,10 @@ class ConfigureCommand(ARouteServerCommand):
 
         if (
             self.answers["daemon"] == "bird" and \
-            version.parse(self.answers["version"]) >= version.parse("2.0")
+            version.parse(self.answers["version"]) >= version.parse("2.0") and \
+            version.parse(self.answers["version"]) <= version.parse("2.0.7")
         ):
+            # Why? See comments in v1.0.1 about the 'receive limit' bug in 2.0.7.
             filtering["max_prefix"]["count_rejected_routes"] = False
             self.notes.append(
                 "Rejected routes are not counted towards max-prefix limit."
