@@ -188,7 +188,7 @@ class OpenBGPDInstance(object):
             if last_line_new_route:
                 raw_as_path = line
                 if "{" in raw_as_path:
-                    # Stripping as_set in strings like this:
+                    # Stripping as_set in strings like this:
                     #   222 333 { 333 333 }
                     as_path = raw_as_path[0:raw_as_path.index("{")].strip()
                     as_set = raw_as_path[raw_as_path.index("{") + 1:-1].strip()
@@ -265,6 +265,9 @@ class OpenBGPDInstance(object):
                 return True
         return False
 
+    def clear_cached_routes(self):
+        self.routes = {}
+
     def get_routes(self, prefix, include_filtered=False, only_best=False):
         if include_filtered and only_best:
             raise Exception("Can't set both include_filtered and only_best")
@@ -369,7 +372,7 @@ class OpenBGPDClassicInstance(OpenBGPDInstance, KVMInstance):
             return False, ""
         return False
 
-class OpenBGPDPortableInstance(OpenBGPDInstance, DockerInstance):
+class OpenBGPDPortableInstance(OpenBGPDInstance, DockerInstance, BGPSpeakerInstance):
     """This class implements OpenBGPD-specific methods for the Portable edition.
 
     This class is derived from :class:`DockerInstance`, that implements
@@ -489,8 +492,17 @@ class OpenBGPD68Instance(OpenBGPDClassicInstance):
     BGP_SPEAKER_VERSION = "6.8"
     TARGET_VERSION = "6.8"
 
-OpenBGPDPreviousInstance = OpenBGPD67Instance
-OpenBGPDLatestInstance = OpenBGPD68Instance
+class OpenBGPD69Instance(OpenBGPDClassicInstance):
+
+    VIRSH_DOMAINNAME = "arouteserver_openbgpd69"
+
+    TAG = "openbgpd69"
+
+    BGP_SPEAKER_VERSION = "6.9"
+    TARGET_VERSION = "6.9"
+
+OpenBGPDPreviousInstance = OpenBGPD68Instance
+OpenBGPDLatestInstance = OpenBGPD69Instance
 
 class OpenBGPD65PortableInstance(OpenBGPDPortableInstance):
 
@@ -528,4 +540,16 @@ class OpenBGPD68PortableInstance(OpenBGPDPortableInstance):
     # TARGET_VERSION not set here because it's assumed to be
     # the same of the OpenBGPD Latest one.
 
-OpenBGPDPortableLatestInstance = OpenBGPD68PortableInstance
+
+class OpenBGPD69PortableInstance(OpenBGPDPortableInstance):
+
+    DOCKER_IMAGE = "pierky/openbgpd:6.9p0-patches"
+
+    TAG = "openbgpd69p"
+
+    BGP_SPEAKER_VERSION = "6.9p0"
+    # TARGET_VERSION not set here because it's assumed to be
+    # the same of the OpenBGPD Latest one.
+
+OpenBGPDPortablePreviousInstance = OpenBGPD68PortableInstance
+OpenBGPDPortableLatestInstance = OpenBGPD69PortableInstance
